/*************************************************************************
 *
 * AIZO CONFIDENTIAL
 * __________________
 *
 *  [2011] - [2012] AIZO AG
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Aizo AG. The intellectual and technical concepts
 * contained herein are proprietary to Aizo AG and may be covered
 * by European and Foreign Patents, patents in process, and are
 * protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from AIZO AG.
 */

Ext.define('DSS.addon.Metering.stores.CircuitModel', {
    extend : 'Ext.data.Model',
    fields : ['name', 'dsid', 'text'],
    proxy : {
        type : 'ajax',
        actionMethods : {
            read : 'GET'
        },
        url : '/json/apartment/getCircuits',
        pageParam : undefined,
        limitParam : undefined,
        startParam : undefined,
        reader : {
            type : 'json',
            root : 'result.circuits',
            successProperty : 'ok'
        }
    },

    constructor : function(data) {
        data.text = data.name || data.dsid.toString().slice(16);

        this.callParent(arguments);
    }
});

Ext.define('DSS.addon.Metering.stores.CircuitViewStore', {
    extend : 'Ext.data.Store',
    model : 'DSS.addon.Metering.stores.CircuitModel',

    /*
     * load function must be overridden so that new records are appended
     * instead of dropping existing records
     */

    load : function(options) {
        var me = this;
        options = options || {};

        if(Ext.isFunction(options)) {
            options = {
                callback : options
            };
        }

        Ext.applyIf(options, {
            groupers : me.groupers.items,
            page : me.currentPage,
            start : (me.currentPage - 1) * me.pageSize,
            limit : me.pageSize,
            addRecords : true
        });

        return me.callParent([options]);
    }
});

Ext.define('DSS.addon.Metering.stores.ResolutionModel', {
    extend : 'Ext.data.Model',
    fields : ['resolution', 'name'],
    proxy : {
        type : 'ajax',
        actionMethods : {
            read : 'GET'
        },
        url : '/json/metering/getResolutions',
        pageParam : undefined,
        limitParam : undefined,
        startParam : undefined,
        reader : {
            type : 'json',
            root : 'result.resolutions',
            successProperty : 'ok'
        }
    },
    setName : function(name) {
        this.set('name', name);
    }
});

Ext.define('DSS.addon.Metering.stores.ResolutionStore', {
    extend : 'Ext.data.Store',
    model : 'DSS.addon.Metering.stores.ResolutionModel',
    autoload : true
});

Ext.define('DSS.addon.Metering.stores.SceneNameModel', {
    extend : 'Ext.data.Model',
    fields : [{
        name : 'id',
        type : 'integer',
        persist : false,
        defaultValue : 0
    }],

    hasMany : {
        name : 'zones',
        model : 'DSS.addon.Metering.stores.ZoneNameModel'
    },

    proxy : {
        type : 'ajax',
        actionMethods : {
            read : 'GET'
        },
        url : '/json/property/query?query=/apartment/zones/*(ZoneID,name,scenes)/groups/*(group)/scenes/*(scene,name)',
        pageParam : undefined,
        limitParam : undefined,
        startParam : undefined,
        reader : {
            type : 'json',
            root : 'result',
            successProperty : 'ok'
        }
    }
});

Ext.define('DSS.addon.Metering.stores.SceneNameStore', {
    extend : 'Ext.data.Store',
    model : 'DSS.addon.Metering.stores.SceneNameModel',
    autoload : true
});

Ext.define('DSS.addon.Metering.stores.ZoneNameModel', {
    extend : 'Ext.data.Model',
    fields : ['ZoneID', 'name', 'text'],
    idProperty : 'ZoneID',
    hasMany : {
        name : 'groups',
        model : 'DSS.addon.Metering.stores.GroupNameModel'
    },

    constructor : function(data, iid) {
        data.text = data.name || data.ZoneID;

        this.callParent(arguments);
    }
});

Ext.define('DSS.addon.Metering.stores.GroupNameModel', {
    extend : 'Ext.data.Model',
    fields : ['group'],
    idProperty : 'group',
    hasMany : {
        name : 'scenes',
        model : 'DSS.addon.Metering.stores.MySceneModel'
    }
});

Ext.define('DSS.addon.Metering.stores.MySceneModel', {
    extend : 'Ext.data.Model',
    fields : ['scene', 'name'],
    belongsTo : {
        name : 'group',
        model : 'DSS.addon.Metering.stores.GroupNameModel'
    },
    idProperty : 'scene'
});
